"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const i18n_class_1 = require("../lib/i18n.class");
const i18n_errors_1 = require("../lib/i18n.errors");
const mockLanguagePacks = {
    'en-US': {
        text1: 'This is text 1',
        text2: 'This is text 2'
    },
    'zh-CN': {
        text1: '这是中文1'
    }
};
describe('test i18n.class', () => {
    it('should get text ok', () => {
        const i18n = i18n_class_1.I18N.createByLanguagePacks(mockLanguagePacks);
        expect(i18n.getText('text1')).toBe('This is text 1');
        i18n.setLanguage('zh-CN');
        expect(i18n.getText('text1')).toBe('这是中文1');
        expect(() => i18n.getText('text2')).toThrow(i18n_errors_1.StringNotFoundError);
        i18n.setLanguage('ja-JP');
        expect(() => i18n.getText('text2')).toThrow(i18n_errors_1.LanguagePackNotFoundError);
        expect(() => i18n.getText('')).toThrow(i18n_errors_1.StringKeyError);
        expect(i18n.language).toBe('ja-JP');
    });
});
//# sourceMappingURL=i18n.test.js.map